@@ -238,11 +238,14 @@ class TestWarningIssueChecking:
         assert "W010" in issues[0].rule.code
 
     def test_unicode_problematic_command(self) -> None:
-        """Test Unicode problematic command."""
+        """Test Unicode problematic command with actual Unicode content."""
         set_vars: Set[str] = set()
-        issues = _check_warning_issues("type unicode_file.txt", 1, set_vars, False)
-        assert len(issues) == 1
-        assert "W011" in issues[0].rule.code
+        # Test with actual Unicode content that should trigger the warning
+        issues = _check_warning_issues("type unicode_filé.txt", 1, set_vars, False)
+        # Multiple Unicode-related warnings may be triggered
+        w011_issues = [i for i in issues if i.rule.code == "W011"]
+        assert len(w011_issues) == 1
+        assert "type" in w011_issues[0].context
 
     def test_non_ascii_characters(self) -> None:
         """Test non-ASCII character detection."""
@@ -278,9 +281,25 @@ class TestStyleIssueChecking:
 
     def test_command_casing_inconsistency(self) -> None:
         """Test command casing inconsistency detection."""
-        issues = _check_style_issues("echo hello", 1)
-        assert len(issues) == 1
-        assert "S003" in issues[0].rule.code
+        # The new S003 rule only flags inconsistencies within the same file
+        # So we need to create content with mixed casing for the same command
+        # Use actual batch commands (not echo, which is often skipped)
+        test_lines = [
+            "set var1=hello",  # lowercase
+            "SET var2=world",  # uppercase - this should trigger S003
+        ]
+        all_issues = []
+        for line_num, line in enumerate(test_lines, 1):
+            issues = _check_style_issues(line, line_num)
+            all_issues.extend(issues)
+
+        # Now check using the global function that detects inconsistencies
+        from blinter import _check_cmd_case_consistency
+
+        consistency_issues = _check_cmd_case_consistency(test_lines)
+
+        assert len(consistency_issues) >= 1
+        assert "S003" in consistency_issues[0].rule.code
 
 
 class TestSecurityIssueChecking:
@@ -461,6 +480,17 @@ class TestGlobalFunctionChecking:
             "echo more",
             "echo content",
             "echo here",
+            "echo line 6",
+            "echo line 7",
+            "echo line 8",
+            "echo line 9",
+            "echo line 10",
+            "echo line 11",
+            "echo line 12",
+            "echo line 13",
+            "echo line 14",
+            "echo line 15",
+            "echo line 16",  # Now 16 lines, should trigger S013
         ]
         from blinter import _check_missing_header_doc
 
@@ -935,7 +965,8 @@ class TestWarningChecking:
     def test_older_windows_commands(self) -> None:
         """Test detection of older Windows commands."""
         set_vars: set[str] = set()
-        for cmd in ["choice", "forfiles", "where", "robocopy", "timeout", "icacls"]:
+        # Removed "timeout" as it's been available since Windows Vista
+        for cmd in ["choice", "forfiles", "where", "robocopy", "icacls"]:
             issues = _check_warning_issues(f"{cmd} /param", 1, set_vars, False)
             warning_issues = [i for i in issues if i.rule.code == "W009"]
             assert len(warning_issues) == 1
@@ -963,13 +994,34 @@ class TestWarningChecking:
         assert len(warning_issues) == 0  # Won't match because pattern expects \\(x86\\)
 
     def test_unicode_problematic_commands(self) -> None:
-        """Test detection of Unicode problematic commands."""
+        """Test detection of Unicode problematic commands with actual Unicode risks."""
         set_vars: set[str] = set()
-        for cmd in ["type", "echo", "find", "findstr"]:
-            issues = _check_warning_issues(f"{cmd} filename", 1, set_vars, False)
-            warning_issues = [i for i in issues if i.rule.code == "W011"]
-            assert len(warning_issues) == 1
-            assert cmd in warning_issues[0].context
+        # Test commands with actual Unicode content that should be flagged
+        issues = _check_warning_issues("type unicode_filé.txt", 1, set_vars, False)
+        warning_issues = [i for i in issues if i.rule.code == "W011"]
+        # The improved rule should still catch this because it has Unicode in filename
+        assert len(warning_issues) == 1
+        assert "type" in warning_issues[0].context
+
+        # Test find/findstr with Unicode content
+        issues = _check_warning_issues("findstr /i pattérn file.txt", 1, set_vars, False)
+        warning_issues = [i for i in issues if i.rule.code == "W011"]
+        assert len(warning_issues) == 1
+
+        # Test echo with non-ASCII - should be flagged
+        issues = _check_warning_issues("echo héllo", 1, set_vars, False)
+        warning_issues = [i for i in issues if i.rule.code == "W011"]
+        assert len(warning_issues) == 1
+
+        # Test echo with redirection - improved rule now considers this safe
+        issues = _check_warning_issues("echo test > file", 1, set_vars, False)
+        warning_issues = [i for i in issues if i.rule.code == "W011"]
+        assert len(warning_issues) == 0  # Now considered safe by improved rule
+
+        # Test simple echo - should NOT be flagged
+        issues = _check_warning_issues("echo simple text", 1, set_vars, False)
+        warning_issues = [i for i in issues if i.rule.code == "W011"]
+        assert len(warning_issues) == 0
 
     def test_non_ascii_character_detection(self) -> None:
         """Test detection of non-ASCII characters."""
@@ -1004,12 +1056,23 @@ class TestStyleChecking:
 
     def test_command_casing_detection(self) -> None:
         """Test command casing consistency detection."""
-        keywords = ["echo", "set", "if", "for", "goto", "call"]
+        # Test with commands that are actually processed (not echo which is often skipped)
+        keywords = ["set", "if", "for", "goto", "call", "cd"]
         for keyword in keywords:
-            issues = _check_style_issues(f"{keyword} test", 1)
-            casing_issues = [i for i in issues if i.rule.code == "S003"]
-            assert len(casing_issues) == 1
-            assert keyword in casing_issues[0].context
+            # Create inconsistent casing for the same command within a file
+            test_lines = [
+                f"{keyword} test",  # lowercase
+                f"{keyword.upper()} test2",  # uppercase - should trigger S003
+            ]
+
+            from blinter import _check_cmd_case_consistency
+
+            consistency_issues = _check_cmd_case_consistency(test_lines)
+            casing_issues = [i for i in consistency_issues if i.rule.code == "S003"]
+            assert len(casing_issues) >= 1, f"No S003 issues found for keyword: {keyword}"
+            # Check that the keyword appears in one of the contexts
+            contexts = [issue.context for issue in casing_issues]
+            assert any(keyword in context.lower() for context in contexts)
 
 
 class TestSecurityChecking:
@@ -1039,7 +1102,7 @@ class TestSecurityChecking:
             ("reg add hklm", "reg add hklm"),
             ("reg delete hklm", "reg delete hklm"),
             ("sc config", "sc"),
-            ("net user", "net"),
+            ("net user", "NET command"),
         ]
         for cmd, expected in admin_commands:
             issues = _check_security_issues(f"{cmd} something", 1)
@@ -1204,14 +1267,20 @@ class TestGlobalChecks:
     def test_check_code_duplication(self) -> None:
         """Test code duplication detection."""
         # Code duplication needs 3+ similar commands AND normalized length > 20
-        # "copy FILE FILE" is only 14 chars, so need longer normalized commands
+        # Note: The new implementation requires normalized commands > 40 chars and uses
+        # adaptive thresholds based on script size. For very small scripts (< 100 lines),
+        # the threshold is 3+ occurrences within 100 lines of each other.
         lines = [
-            "copy longfile.txt to backup\\longfile.txt with extra text here",
-            "copy longfile2.txt to backup\\longfile2.txt with extra text here",
-            "copy longfile3.txt to backup\\longfile3.txt with extra text here",
-            "copy longfile4.txt to backup\\longfile4.txt with extra text here",
+            "robocopy %SOURCE% %DEST% /MIR /COPYALL /R:3 /W:10 "
+            "/LOG:backup.log with some extra text",
+            "robocopy %SOURCE% %DEST% /MIR /COPYALL /R:3 /W:10 "
+            "/LOG:backup2.log with some extra text",
+            "robocopy %SOURCE% %DEST% /MIR /COPYALL /R:3 /W:10 "
+            "/LOG:backup3.log with some extra text",
+            "robocopy %SOURCE% %DEST% /MIR /COPYALL /R:3 /W:10 "
+            "/LOG:backup4.log with some extra text",
         ]
-        # This should normalize to "copy FILE to FILE with extra text here" which is > 20 chars
+        # This normalizes variables to VAR and files to FILE, all should be identical
         issues = _check_code_duplication(lines)
         duplication_issues = [i for i in issues if i.rule.code == "P002"]
         assert len(duplication_issues) == 3  # Lines 2, 3 and 4 should be flagged
